┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphintabwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dolphintabwidget.h')
-rw-r--r--src/dolphintabwidget.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/src/dolphintabwidget.h b/src/dolphintabwidget.h
index a84b7facb..7b3a18814 100644
--- a/src/dolphintabwidget.h
+++ b/src/dolphintabwidget.h
@@ -98,17 +98,18 @@ public slots:
void openNewTab(const QUrl &primaryUrl, const QUrl &secondaryUrl = QUrl());
/**
* Opens each directory in \p dirs in a separate tab. If the "split view"
* option is enabled, 2 directories are collected within one tab.
*/
- void openDirectories(const QList<QUrl>& dirs);
+ void openDirectories(const QList<QUrl>& dirs, bool splitView);
/**
- * Opens the directory which contains the files \p files
- * and selects all files (implements the --select option
- * of Dolphin).
+ * Opens the directories which contain the files \p files and selects all files.
+ * If \a splitView is set, 2 directories are collected within one tab.
+ * \pre \a files must contain at least one url.
*/
- void openFiles(const QList<QUrl> &files);
+ void openFiles(const QList<QUrl> &files, bool splitView);
/**
* Closes the currently active tab.
@@ -98,17 +98,18 @@ public slots:
void openNewTab(const QUrl &primaryUrl, const QUrl &secondaryUrl = QUrl());
/**
- * Opens each directory in \p dirs in a separate tab. If the "split view"
- * option is enabled, 2 directories are collected within one tab.
+ * Opens each directory in \p dirs in a separate tab. If \a splitView is set,
+ * 2 directories are collected within one tab.
+ * \pre \a dirs must contain at least one url.
*/